@@ -8,6 +8,6 @@ class InfraConfig(ResourceConfigMixin):
 
 
 class InfraConfigMixin(BaseModel):
-    infra: Annotated[
-        InfraConfig, Field(default_factory=InfraConfig, description="Infra config")
-    ] = InfraConfig()
+    infra: Annotated[InfraConfig, Field(InfraConfig(), description="Infra config")] = (
+        InfraConfig()
+    )
